pub struct Config {
pub ip_geo_provider: IpGeoProviderType,
pub mmdb_path: Option<String>,
pub test_subnets: HashMap<String, RoutingCountryConfig>,
pub domain: Vec<DomainConfig>,
}Expand description
A struct to hold the parsed config
Fields
ip_geo_provider: IpGeoProviderTypeThe IP geo provider
mmdb_path: Option<String>test_subnets: HashMap<String, RoutingCountryConfig>A map of country codes to their respective subnets
domain: Vec<DomainConfig>A list of domains and their respective geo routing